/*
 * DYNAMIC AMBIENT LIGHT FOR ICE SKETCH
 * Main core library for firmware.
 * Core version 1.0.1
 * dalscore.h
 *
 * Created: 09.12.2012 15:08:49
 *  Author: Vladimir Inshakov, Russia, Elets town. e-mail: markoni48@yandex.ru
 *
 *        
 *  AVR ATmega168/328.      , 
 *        .
 */ 


#ifndef DYNSKETCH_H_
#define DYNSKETCH_H_

#include <inttypes.h>
#include <avr/io.h>


//     .
typedef struct _stp16_interface
{
	uint16_t led13:1;
	uint16_t led12:1;
	uint16_t led11:1;
	uint16_t led10:1;
	uint16_t :1;	// 
	uint16_t :1;	// 
	uint16_t :1;	// 
	uint16_t :1;	// 
	uint16_t led9:1;
	uint16_t led8:1;
	uint16_t led2:1;
	uint16_t led3:1;
	uint16_t led4:1;
	uint16_t led5:1;
	uint16_t led6:1;
	uint16_t led7:1;
	uint8_t dimmer;
} stp16_d;

//  LED-  .
void stp16_sendData(stp16_d*);

//  LED-     .
void stp16_sendWord(uint16_t);

/*     
(!    DC-DC    )/ */
#define stp16_allLedsOn() (stp16_sendWord(0xFFFF))

//   /
#define stp16_allLedsOff() (stp16_sendWord(0))

//    (  )
#define dimmer_setIntensity(brightness) (OCR2B = brightness)

//   (. 0)
#define dimmer_lightMax() (OCR2B = 0xFF)

//   (. 1)
#define dimmer_lightOff() (OCR2B = 0x0)


/*  Custom Variable     . 
        ,   -
 (SLAVE)       . */
typedef union _t_actor_custom_var {
	
	uint8_t ui8;
	uint16_t ui16;
	int8_t i8;
	int16_t i16;
	uint8_t array[3];

} actorCustomVar;

/*  -,     ActorList.     , 
       ,     
  (.  ).         250 ,
     . */
typedef void (*actor)(uint16_t phase, actorCustomVar* CustomVar);


/*    .   EEPROM,   .  
      EEPROM,        .

   ,     , .  :
\CODE

#include "dalscore.h"
...
extern firmware_propperties_t Config;	//     Config
...
a = Config.secretKey;	//     .

\END CODE
 */
typedef struct {
	
	uint8_t secretKey;		//   -,     
	uint16_t timeout;		//   
	uint8_t isMaster:1;		//   (1)/(0).     
	uint8_t isDemo:1;		//    DEMO
	uint8_t :6;
	uint8_t ir_freq;		//   -
	int16_t actorPlayTime; //     ( )
	uint16_t abTimeout;		//   
	uint8_t batLowLevel;	//    

	char Name[16];
	char fVer[10];
	char Date[8];
	char :8;
	char Vendor[21];
	
} firmware_propperties_t;


#endif /* DYNSKETCH_H_ */